Struct BeginSynchronizedUpdate
pub struct BeginSynchronizedUpdate;Available on crate feature
term only.Expand description
A command that instructs the terminal emulator to begin a synchronized frame.
Notes
- Commands must be executed/queued for execution otherwise they do nothing.
- Use EndSynchronizedUpdate command to leave the entered alternate screen.
When rendering the screen of the terminal, the Emulator usually iterates through each visible grid cell and renders its current state. With applications updating the screen at a higher frequency this can cause tearing.
This mode attempts to mitigate that.
When the synchronization mode is enabled following render calls will keep rendering the last rendered state. The terminal Emulator keeps processing incoming text and sequences. When the synchronized update mode is disabled again the renderer may fetch the latest screen buffer state again, effectively avoiding the tearing effect by unintentionally rendering in the middle a of an application screen update.
Examples
use std::io::{self, Write};
use crossterm::{execute, terminal::{BeginSynchronizedUpdate, EndSynchronizedUpdate}};
fn main() -> io::Result<()> {
execute!(io::stdout(), BeginSynchronizedUpdate)?;
// Anything performed here will not be rendered until EndSynchronizedUpdate is called.
execute!(io::stdout(), EndSynchronizedUpdate)?;
Ok(())
}Trait Implementations
impl Clone for BeginSynchronizedUpdate
impl Clone for BeginSynchronizedUpdate
fn clone(&self) -> BeginSynchronizedUpdate
fn clone(&self) -> BeginSynchronizedUpdate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Command for BeginSynchronizedUpdate
impl Command for BeginSynchronizedUpdate
impl Copy for BeginSynchronizedUpdate
impl Debug for BeginSynchronizedUpdate
impl Debug for BeginSynchronizedUpdate
impl Eq for BeginSynchronizedUpdate
impl PartialEq for BeginSynchronizedUpdate
impl PartialEq for BeginSynchronizedUpdate
impl StructuralPartialEq for BeginSynchronizedUpdate